@@ -14,4 +14,6 @@
 __author__ = 'lth'
 
 from .CTC import CTCFormal
-from .GroupNorm import GroupNorm
\ No newline at end of file
+from .GroupNorm import GroupNorm
+from .IdentityNode import IdentityNode
+from .SoftPool import SoftPooling1D,SoftPooling2D,SoftPooling3D
